@@ -1,4 +1,5 @@
 // Package all registers all builtin formats with the default registry
+//
 //nolint:revive
 package all
 
@@ -37,6 +38,7 @@ import (
 	_ "github.com/wader/fq/format/opus"
 	_ "github.com/wader/fq/format/pcap"
 	_ "github.com/wader/fq/format/png"
+	_ "github.com/wader/fq/format/prores"
 	_ "github.com/wader/fq/format/protobuf"
 	_ "github.com/wader/fq/format/raw"
 	_ "github.com/wader/fq/format/rtmp"
@@ -46,6 +48,7 @@ import (
 	_ "github.com/wader/fq/format/toml"
 	_ "github.com/wader/fq/format/vorbis"
 	_ "github.com/wader/fq/format/vpx"
+	_ "github.com/wader/fq/format/wasm"
 	_ "github.com/wader/fq/format/wav"
 	_ "github.com/wader/fq/format/webp"
 	_ "github.com/wader/fq/format/xml"
