@@ -10,7 +10,7 @@ type BytesCodec struct{}
 
 func decodeBytesFn(sms ...scalar.Mapper) (DecodeFn, error) {
 	// Bytes are encoded as a long followed by that many bytes of data.
-	return func(name string, d *decode.D) interface{} {
+	return func(name string, d *decode.D) any {
 		var val []byte
 
 		d.FieldStruct(name, func(d *decode.D) {
