@@ -8,7 +8,7 @@ import (
 func decodeFloatFn(sms ...scalar.Mapper) (DecodeFn, error) {
 	// A float is written as 4 bytes. The float is converted into a 32-bit integer using a method equivalent to Java's
 	// floatToIntBits and then encoded in little-endian format.
-	return func(name string, d *decode.D) interface{} {
+	return func(name string, d *decode.D) any {
 		return d.FieldF32(name, sms...)
 	}, nil
 }
