@@ -11,7 +11,7 @@ func decodeStringFn(schema schema.SimplifiedSchema, sms ...scalar.Mapper) (Decod
 	// For example, the three-character string "foo" would be encoded as the long value 3 (encoded as hex 06) followed
 	// by the UTF-8 encoding of 'f', 'o', and 'o' (the hex bytes 66 6f 6f):
 	// 06 66 6f 6f
-	return func(name string, d *decode.D) interface{} {
+	return func(name string, d *decode.D) any {
 		var val string
 		d.FieldStruct(name, func(d *decode.D) {
 			length := d.FieldSFn("length", VarZigZag)
