@@ -3,11 +3,13 @@ package format
 // TODO: do before-format somehow and topology sort?
 const (
 	ProbeOrderBinUnique = 0   // binary with unlikely overlap
-	ProbeOrderBinFuzzy  = 50  // binary with possible overlap
-	ProbeOrderText      = 100 // text format
+	ProbeOrderBinFuzzy  = 100 // binary with possible overlap
+	ProbeOrderTextJSON  = 200 // text json has prio as yaml overlap
+	ProbeOrderTextFuzzy = 300 // text with possible overlap
 )
 
 // TODO: change to CamelCase?
+//
 //nolint:revive
 const (
 	ALL = "all"
@@ -81,7 +83,9 @@ const (
 	IPV6_PACKET         = "ipv6_packet"
 	JPEG                = "jpeg"
 	JSON                = "json"
+	JSONL               = "jsonl"
 	MACHO               = "macho"
+	MACHO_FAT           = "macho_fat"
 	MATROSKA            = "matroska"
 	MP3                 = "mp3"
 	MP3_FRAME           = "mp3_frame"
@@ -99,6 +103,7 @@ const (
 	PCAP                = "pcap"
 	PCAPNG              = "pcapng"
 	PNG                 = "png"
+	PRORES_FRAME        = "prores_frame"
 	PROTOBUF            = "protobuf"
 	PROTOBUF_WIDEVINE   = "protobuf_widevine"
 	PSSH_PLAYREADY      = "pssh_playready"
@@ -117,6 +122,7 @@ const (
 	VP9_CFM             = "vp9_cfm"
 	VP9_FRAME           = "vp9_frame"
 	VPX_CCR             = "vpx_ccr"
+	WASM                = "wasm"
 	WAV                 = "wav"
 	WEBP                = "webp"
 	XING                = "xing"
@@ -289,13 +295,15 @@ type ZipIn struct {
 }
 
 type XMLIn struct {
-	Seq   bool `doc:"Use seq attribute to preserve element order"`
-	Array bool `doc:"Decode as nested arrays"`
+	Seq             bool   `doc:"Use seq attribute to preserve element order"`
+	Array           bool   `doc:"Decode as nested arrays"`
+	AttributePrefix string `doc:"Prefix for attribute keys"`
 }
 
 type HTMLIn struct {
-	Seq   bool `doc:"Use seq attribute to preserve element order"`
-	Array bool `doc:"Decode as nested arrays"`
+	Seq             bool   `doc:"Use seq attribute to preserve element order"`
+	Array           bool   `doc:"Decode as nested arrays"`
+	AttributePrefix string `doc:"Prefix for attribute keys"`
 }
 
 type CSVLIn struct {
