@@ -2,20 +2,20 @@ package id3
 
 import (
 	"github.com/wader/fq/format"
-	"github.com/wader/fq/format/registry"
 	"github.com/wader/fq/pkg/decode"
+	"github.com/wader/fq/pkg/interp"
 	"github.com/wader/fq/pkg/scalar"
 )
 
 func init() {
-	registry.MustRegister(decode.Format{
+	interp.RegisterFormat(decode.Format{
 		Name:        format.ID3V11,
 		Description: "ID3v1.1 metadata",
 		DecodeFn:    id3v11Decode,
 	})
 }
 
-func id3v11Decode(d *decode.D, in interface{}) interface{} {
+func id3v11Decode(d *decode.D, _ any) any {
 	d.AssertAtLeastBitsLeft(128 * 8)
 	d.FieldUTF8("magic", 4, d.AssertStr("TAG+"))
 	d.FieldUTF8("title", 60)
