@@ -45,24 +45,24 @@ func tarDecode(d *decode.D, _ any) any {
 		for !d.End() {
 			d.FieldStruct("file", func(d *decode.D) {
 				d.FieldUTF8("name", 100, mapTrimSpaceNull)
-				d.FieldUTF8NullFixedLen("mode", 8, scalar.SymUParseUint(8))
-				d.FieldUTF8NullFixedLen("uid", 8, scalar.SymUParseUint(8))
-				d.FieldUTF8NullFixedLen("gid", 8, scalar.SymUParseUint(8))
-				sizeS := d.FieldScalarUTF8NullFixedLen("size", 12, scalar.SymUParseUint(8))
+				d.FieldUTF8NullFixedLen("mode", 8, scalar.TrySymUParseUint(8))
+				d.FieldUTF8NullFixedLen("uid", 8, scalar.TrySymUParseUint(8))
+				d.FieldUTF8NullFixedLen("gid", 8, scalar.TrySymUParseUint(8))
+				sizeS := d.FieldScalarUTF8NullFixedLen("size", 12, scalar.TrySymUParseUint(8))
 				if sizeS.Sym == nil {
 					d.Fatalf("could not decode size")
 				}
 				size := int64(sizeS.SymU()) * 8
-				d.FieldUTF8NullFixedLen("mtime", 12, scalar.SymUParseUint(8), scalar.DescriptionSymUUnixTime)
-				d.FieldUTF8NullFixedLen("chksum", 8, scalar.SymUParseUint(8))
+				d.FieldUTF8NullFixedLen("mtime", 12, scalar.TrySymUParseUint(8), scalar.DescriptionSymUUnixTime)
+				d.FieldUTF8NullFixedLen("chksum", 8, scalar.TrySymUParseUint(8))
 				d.FieldUTF8("typeflag", 1, mapTrimSpaceNull)
 				d.FieldUTF8("linkname", 100, mapTrimSpaceNull)
 				d.FieldUTF8("magic", 6, mapTrimSpaceNull, d.AssertStr("ustar"))
-				d.FieldUTF8NullFixedLen("version", 2, scalar.SymUParseUint(8))
+				d.FieldUTF8NullFixedLen("version", 2, scalar.TrySymUParseUint(8))
 				d.FieldUTF8("uname", 32, mapTrimSpaceNull)
 				d.FieldUTF8("gname", 32, mapTrimSpaceNull)
-				d.FieldUTF8NullFixedLen("devmajor", 8, scalar.SymUParseUint(8))
-				d.FieldUTF8NullFixedLen("devminor", 8, scalar.SymUParseUint(8))
+				d.FieldUTF8NullFixedLen("devmajor", 8, scalar.TrySymUParseUint(8))
+				d.FieldUTF8NullFixedLen("devminor", 8, scalar.TrySymUParseUint(8))
 				d.FieldUTF8("prefix", 155, mapTrimSpaceNull)
 				d.FieldRawLen("header_block_padding", blockPadding(d), d.BitBufIsZero())
 
