@@ -5,12 +5,11 @@ import (
 	"context"
 	"fmt"
 	"io"
-	"io/ioutil"
 	"math/big"
 	"regexp"
 
-	"github.com/wader/fq/internal/bitioextra"
-	"github.com/wader/fq/internal/ioextra"
+	"github.com/wader/fq/internal/bitioex"
+	"github.com/wader/fq/internal/ioex"
 	"github.com/wader/fq/internal/recoverfn"
 	"github.com/wader/fq/pkg/bitio"
 	"github.com/wader/fq/pkg/ranges"
@@ -46,7 +45,7 @@ func Decode(ctx context.Context, br bitio.ReaderAtSeeker, group Group, opts Opti
 }
 
 func decode(ctx context.Context, br bitio.ReaderAtSeeker, group Group, opts Options) (*Value, any, error) {
-	brLen, err := bitioextra.Len(br)
+	brLen, err := bitioex.Len(br)
 	if err != nil {
 		return nil, nil, err
 	}
@@ -77,7 +76,7 @@ func decode(ctx context.Context, br bitio.ReaderAtSeeker, group Group, opts Opti
 			}
 		}
 
-		cBR, err := bitioextra.Range(br, decodeRange.Start, decodeRange.Len)
+		cBR, err := bitioex.Range(br, decodeRange.Start, decodeRange.Len)
 		if err != nil {
 			return nil, nil, IOError{Err: err, Op: "BitBufRange", ReadSize: decodeRange.Len, Pos: decodeRange.Start}
 		}
@@ -150,11 +149,10 @@ func decode(ctx context.Context, br bitio.ReaderAtSeeker, group Group, opts Opti
 }
 
 type D struct {
-	Ctx         context.Context
-	Endian      Endian
-	RangeSorted bool
-	Value       *Value
-	Options     Options
+	Ctx     context.Context
+	Endian  Endian
+	Value   *Value
+	Options Options
 
 	bitBuf bitio.ReaderAtSeeker
 
@@ -170,15 +168,14 @@ func newDecoder(ctx context.Context, format Format, br bitio.ReaderAtSeeker, opt
 	}
 	rootV := &Compound{
 		IsArray:     format.RootArray,
-		RangeSorted: true,
+		RangeSorted: !format.RootArray,
 		Children:    nil,
 		Description: opts.Description,
 	}
 
 	return &D{
-		Ctx:         ctx,
-		Endian:      BigEndian,
-		RangeSorted: true,
+		Ctx:    ctx,
+		Endian: BigEndian,
 		Value: &Value{
 			Name:       name,
 			V:          rootV,
@@ -194,11 +191,10 @@ func newDecoder(ctx context.Context, format Format, br bitio.ReaderAtSeeker, opt
 	}
 }
 
-func (d *D) FieldDecoder(name string, bitBuf bitio.ReaderAtSeeker, v any) *D {
+func (d *D) fieldDecoder(name string, bitBuf bitio.ReaderAtSeeker, v any) *D {
 	return &D{
-		Ctx:         d.Ctx,
-		Endian:      d.Endian,
-		RangeSorted: true,
+		Ctx:    d.Ctx,
+		Endian: d.Endian,
 		Value: &Value{
 			Name:       name,
 			V:          v,
@@ -215,7 +211,7 @@ func (d *D) FieldDecoder(name string, bitBuf bitio.ReaderAtSeeker, v any) *D {
 func (d *D) TryCopyBits(w io.Writer, r bitio.Reader) (int64, error) {
 	// TODO: what size? now same as io.Copy
 	buf := d.SharedReadBuf(32 * 1024)
-	return bitioextra.CopyBitsBuffer(w, r, buf)
+	return bitioex.CopyBitsBuffer(w, r, buf)
 }
 
 func (d *D) CopyBits(w io.Writer, r bitio.Reader) int64 {
@@ -257,7 +253,7 @@ func (d *D) NewBitBufFromReader(r io.Reader) bitio.ReaderAtSeeker {
 func (d *D) TryReadAllBits(r bitio.Reader) ([]byte, error) {
 	bb := &bytes.Buffer{}
 	buf := d.SharedReadBuf(32 * 1024)
-	if _, err := bitioextra.CopyBitsBuffer(bb, r, buf); err != nil {
+	if _, err := bitioex.CopyBitsBuffer(bb, r, buf); err != nil {
 		return nil, err
 	}
 	return bb.Bytes(), nil
@@ -306,7 +302,7 @@ func (d *D) FillGaps(r ranges.Range, namePrefix string) {
 
 	gaps := ranges.Gaps(r, valueRanges)
 	for i, gap := range gaps {
-		br, err := bitioextra.Range(d.bitBuf, gap.Start, gap.Len)
+		br, err := bitioex.Range(d.bitBuf, gap.Start, gap.Len)
 		if err != nil {
 			d.IOPanic(err, "FillGaps: Range")
 		}
@@ -321,6 +317,7 @@ func (d *D) FillGaps(r ranges.Range, namePrefix string) {
 			Range:      gap,
 		}
 
+		// TODO: for arrays not great that we just append unknown fields
 		d.AddChild(v)
 	}
 }
@@ -523,11 +520,11 @@ func (d *D) BytesLen(nBytes int) []byte {
 
 // TODO: rename/remove BitBuf name?
 func (d *D) TryBitBufRange(firstBit int64, nBits int64) (bitio.ReaderAtSeeker, error) {
-	return bitioextra.Range(d.bitBuf, firstBit, nBits)
+	return bitioex.Range(d.bitBuf, firstBit, nBits)
 }
 
 func (d *D) BitBufRange(firstBit int64, nBits int64) bitio.ReaderAtSeeker {
-	br, err := bitioextra.Range(d.bitBuf, firstBit, nBits)
+	br, err := bitioex.Range(d.bitBuf, firstBit, nBits)
 	if err != nil {
 		panic(IOError{Err: err, Op: "BitBufRange", ReadSize: nBits, Pos: firstBit})
 	}
@@ -547,7 +544,7 @@ func (d *D) Pos() int64 {
 }
 
 func (d *D) TryLen() (int64, error) {
-	return bitioextra.Len(d.bitBuf)
+	return bitioex.Len(d.bitBuf)
 }
 
 func (d *D) Len() int64 {
@@ -755,28 +752,30 @@ func (d *D) FieldMustGet(name string) *Value {
 	panic(fmt.Sprintf("%s not found in struct %s", name, d.Value.Name))
 }
 
+// FieldArray decode array of fields. Will not be range sorted.
 func (d *D) FieldArray(name string, fn func(d *D), sms ...scalar.Mapper) *D {
-	c := &Compound{IsArray: true, RangeSorted: true}
-	cd := d.FieldDecoder(name, d.bitBuf, c)
+	c := &Compound{IsArray: true, RangeSorted: false}
+	cd := d.fieldDecoder(name, d.bitBuf, c)
 	d.AddChild(cd.Value)
 	fn(cd)
-	c.RangeSorted = cd.RangeSorted
 	return cd
 }
 
+// FieldArrayValue decode array of fields. Will not be range sorted.
 func (d *D) FieldArrayValue(name string) *D {
 	return d.FieldArray(name, func(d *D) {})
 }
 
+// FieldStruct decode array of fields. Will be range sorted.
 func (d *D) FieldStruct(name string, fn func(d *D)) *D {
 	c := &Compound{IsArray: false, RangeSorted: true}
-	cd := d.FieldDecoder(name, d.bitBuf, c)
+	cd := d.fieldDecoder(name, d.bitBuf, c)
 	d.AddChild(cd.Value)
 	fn(cd)
-	c.RangeSorted = cd.RangeSorted
 	return cd
 }
 
+// FieldStructValue decode array of fields. Will be range sorted.
 func (d *D) FieldStructValue(name string) *D {
 	return d.FieldStruct(name, func(d *D) {})
 }
@@ -1072,7 +1071,7 @@ func (d *D) FieldFormatBitBuf(name string, br bitio.ReaderAtSeeker, group Group,
 // TODO: rethink these
 
 func (d *D) FieldRootBitBuf(name string, br bitio.ReaderAtSeeker, sms ...scalar.Mapper) *Value {
-	brLen, err := bitioextra.Len(br)
+	brLen, err := bitioex.Len(br)
 	if err != nil {
 		d.IOPanic(err, "br Len")
 	}
@@ -1094,12 +1093,11 @@ func (d *D) FieldRootBitBuf(name string, br bitio.ReaderAtSeeker, sms ...scalar.
 }
 
 func (d *D) FieldArrayRootBitBufFn(name string, br bitio.ReaderAtSeeker, fn func(d *D)) *Value {
-	c := &Compound{IsArray: true, RangeSorted: true}
-	cd := d.FieldDecoder(name, br, c)
+	c := &Compound{IsArray: true, RangeSorted: false}
+	cd := d.fieldDecoder(name, br, c)
 	cd.Value.IsRoot = true
 	d.AddChild(cd.Value)
 	fn(cd)
-	c.RangeSorted = cd.RangeSorted
 
 	cd.Value.postProcess()
 
@@ -1108,11 +1106,10 @@ func (d *D) FieldArrayRootBitBufFn(name string, br bitio.ReaderAtSeeker, fn func
 
 func (d *D) FieldStructRootBitBufFn(name string, br bitio.ReaderAtSeeker, fn func(d *D)) *Value {
 	c := &Compound{IsArray: false, RangeSorted: true}
-	cd := d.FieldDecoder(name, br, c)
+	cd := d.fieldDecoder(name, br, c)
 	cd.Value.IsRoot = true
 	d.AddChild(cd.Value)
 	fn(cd)
-	c.RangeSorted = cd.RangeSorted
 
 	cd.Value.postProcess()
 
@@ -1131,7 +1128,7 @@ func (d *D) FieldFormatReaderLen(name string, nBits int64, fn func(r io.Reader)
 	if err != nil {
 		d.IOPanic(err, "FieldFormatReaderLen: fn")
 	}
-	rBuf, err := ioutil.ReadAll(r)
+	rBuf, err := io.ReadAll(r)
 	if err != nil {
 		d.IOPanic(err, "FieldFormatReaderLen: ReadAll")
 	}
@@ -1151,7 +1148,7 @@ func (d *D) TryFieldReaderRangeFormat(name string, startBit int64, nBits int64,
 		return 0, nil, nil, nil, err
 	}
 	r := bitio.NewIOReadSeeker(br)
-	rb, err := ioutil.ReadAll(fn(r))
+	rb, err := io.ReadAll(fn(r))
 	if err != nil {
 		return 0, nil, nil, nil, err
 	}
@@ -1236,7 +1233,7 @@ func (d *D) RE(reRef **regexp.Regexp, reStr string) []ranges.Range {
 
 	startPos := d.Pos()
 
-	rr := ioextra.ByteRuneReader{RS: bitio.NewIOReadSeeker(d.bitBuf)}
+	rr := ioex.ByteRuneReader{RS: bitio.NewIOReadSeeker(d.bitBuf)}
 	locs := (*reRef).FindReaderSubmatchIndex(rr)
 	if locs == nil {
 		return nil
