@@ -5,7 +5,8 @@ import (
 	"math/big"
 	"strconv"
 
-	"github.com/wader/fq/internal/mathextra"
+	"github.com/wader/fq/internal/mathex"
+	"github.com/wader/fq/internal/stringsex"
 	"github.com/wader/fq/pkg/bitio"
 	"github.com/wader/fq/pkg/scalar"
 )
@@ -19,26 +20,23 @@ func previewValue(v any, df scalar.DisplayFormat) string {
 		return "false"
 	case int:
 		// TODO: DisplayFormat is weird
-		return mathextra.PadFormatInt(int64(vv), df.FormatBase(), true, 0)
+		return mathex.PadFormatInt(int64(vv), df.FormatBase(), true, 0)
 	case int64:
 		// TODO: DisplayFormat is weird
-		return mathextra.PadFormatInt(vv, df.FormatBase(), true, 0)
+		return mathex.PadFormatInt(vv, df.FormatBase(), true, 0)
 	case uint64:
-		return mathextra.PadFormatUint(vv, df.FormatBase(), true, 0)
+		return mathex.PadFormatUint(vv, df.FormatBase(), true, 0)
 	case float64:
 		// TODO: float32? better truncated to significant digits?
 		return strconv.FormatFloat(vv, 'g', -1, 64)
 	case string:
-		if len(vv) > 50 {
-			return fmt.Sprintf("%q", vv[0:50]) + "..."
-		}
-		return fmt.Sprintf("%q", vv)
+		return fmt.Sprintf("%q", stringsex.TrimN(vv, 50, "..."))
 	case nil:
 		return "null"
 	case bitio.Reader:
 		return "raw bits"
 	case *big.Int:
-		return mathextra.PadFormatBigInt(vv, df.FormatBase(), true, 0)
+		return mathex.PadFormatBigInt(vv, df.FormatBase(), true, 0)
 	default:
 		panic("unreachable")
 	}
